@@ -1,10 +1,11 @@
-//$Id: kmag.cpp,v 1.36 2003/03/06 13:02:41 ojschmidt Exp $
 /***************************************************************************
                           kmag.cpp  -  description
                              -------------------
     begin                : Mon Feb 12 23:45:41 EST 2001
     copyright            : (C) 2001-2003 by Sarang Lakare
-    email                : sarang@users.sourceforge.net
+    email                : sarang#users.sourceforge.net
+    copyright            : (C) 2003 by Olaf Schmidt
+    email                : ojschmidt@kde.org
  ***************************************************************************/
 
 /***************************************************************************
@@ -21,14 +22,12 @@
 #include <qdir.h>
 #include <qprinter.h>
 #include <qpainter.h>
-#include <qvbox.h>
-#include <qcheckbox.h>
-#include <qbuttongroup.h>
 #include <qlayout.h>
 #include <qclipboard.h>
 #include <qdragobject.h>
 #include <qwhatsthis.h>
 #include <qtooltip.h>
+#include <qpopupmenu.h>
 
 #include <kdeversion.h>
 
@@ -85,7 +84,7 @@ KmagApp::KmagApp(QWidget* , const char* name)
   zoomArray.push_back(4.0); zoomArray.push_back(5.0); zoomArray.push_back(6.0); zoomArray.push_back(7.0);
   zoomArray.push_back(8.0); zoomArray.push_back(12.0); zoomArray.push_back(16.0); zoomArray.push_back(20.0);
 
-  fpsArrayString << i18n("Very Low") << i18n("Low") << i18n("Medium") << i18n("High") << i18n("Very High");
+  fpsArrayString << i18n("&Very Low") << i18n("&Low") << i18n("&Medium") << i18n("&High") << i18n("V&ery High");
 
   fpsArray.push_back(2); // very low
   fpsArray.push_back(6); // low
@@ -124,30 +123,60 @@ void KmagApp::initActions()
                               SLOT(slotFileNewWindow()), actionCollection(),"new_window");
   fileNewWindow->setToolTip(i18n("Open a new KMagnifier window"));
 
-  refreshSwitch = new KAction(i18n("Stop"), "stop", KStdAccel::key(KStdAccel::Reload), this,
+  refreshSwitch = new KAction(i18n("&Stop"), "stop", KStdAccel::key(KStdAccel::Reload), this,
                               SLOT(slotToggleRefresh()), actionCollection(), "start_stop_refresh");
   refreshSwitch->setToolTip(i18n("Click to stop window refresh"));
   refreshSwitch->setWhatsThis(i18n("Clicking on this icon will <b>start</b> / <b>stop</b>\
   updating of the display. Stopping the update will zero the processing power\
   required (CPU usage)"));
 
-  m_pSnapshot = new KAction(i18n("&Snapshot"), "ksnapshot", KStdAccel::key(KStdAccel::Save), this,
+  m_pSnapshot = new KAction(i18n("&Save Snapshot As..."), "ksnapshot", KStdAccel::key(KStdAccel::Save), this,
                             SLOT(saveZoomPixmap()), actionCollection(),"snapshot");
-  m_pSnapshot->setWhatsThis(i18n("Click to save the zoomed view to an image file."));
+  m_pSnapshot->setWhatsThis(i18n("Saves the zoomed view to an image file."));
   m_pSnapshot->setToolTip(i18n("Save image to a file"));
 
   m_pPrint = KStdAction::print(this, SLOT(slotFilePrint()), actionCollection(), "print");
   m_pPrint->setWhatsThis(i18n("Click on this button to print the current zoomed view."));
 
+  m_pQuit = KStdAction::quit(this, SLOT(slotFileQuit()), actionCollection(), "quit");
+  m_pQuit->setStatusText(i18n("Quits the application"));
+  m_pQuit->setWhatsThis (i18n("Quits the application"));
+
   m_pCopy = KStdAction::copy(this, SLOT(copyToClipBoard()), actionCollection(), "copy");
   m_pCopy->setWhatsThis(i18n("Click on this button to copy the current zoomed view to the clipboard which you can paste in other applications."));
   m_pCopy->setToolTip(i18n("Copy zoomed image to clipboard"));
 
+  m_pShowMenu = new KToggleAction(i18n("Show &Menu"), "showmenu", CTRL+Key_M, this,
+                            SLOT(slotShowMenu()), actionCollection(),"show_menu");
+  m_pShowMainToolBar = new KToggleAction(i18n("Show Main &Toolbar"), 0, 0, this,
+                            SLOT(slotShowMainToolBar()), actionCollection(),"show_mainToolBar");
+  m_pShowViewToolBar = new KToggleAction(i18n("Show &View Toolbar"), 0, 0, this,
+                            SLOT(slotShowViewToolBar()), actionCollection(),"show_viewToolBar");
+  m_pShowSettingsToolBar = new KToggleAction(i18n("Show &Settings Toolbar"), 0, 0, this,
+                            SLOT(slotShowSettingsToolBar()), actionCollection(),"show_settingsToolBar");
+
+
+  m_alwaysFit = new KToggleAction(i18n("&Always Fit Window"), "", CTRL+SHIFT+Key_F, this,
+                            SLOT(slotAlwaysFit()), actionCollection(),"always_fit");
+
   m_fitToWindow = new KAction(i18n("&Fit Window"), "window_fullscreen", CTRL+Key_F, m_zoomView,
                               SLOT(fitToWindow()), actionCollection(),"fit_to_window");
   m_fitToWindow->setWhatsThis(i18n("Click on this button to fit the zoom view to the zoom window."));
   m_fitToWindow->setToolTip(i18n("Maximize the use of the window"));
 
+  m_followMouse = new KToggleAction(i18n("&Follow Mouse"), "followmouse", 0, this,
+                            SLOT(slotToggleFollowMouse()), actionCollection(), "followmouse");
+  m_followMouse->setToolTip(i18n("Magnify around the mouse cursor"));
+  m_followMouse->setWhatsThis(i18n("If selected, the area around the mouse cursor is magnified"));
+
+  m_hideCursor = new KToggleAction(i18n("Hide Mouse &Cursor"), "hidemouse", 0, this,
+                            SLOT(slotToggleHideCursor()), actionCollection(), "hidecursor");
+  m_hideCursor->setToolTip(i18n("Hide the mouse cursor"));
+
+  m_showSelRect = new KToggleAction(i18n("Selection &Window"), "window", 0, this,
+                            SLOT(slotToggleShowSelRect()), actionCollection(), "selectionwindow");
+  m_showSelRect->setToolTip(i18n("Show the selection window on the screen"));
+
   m_pZoomIn = KStdAction::zoomIn(this, SLOT(zoomIn()), actionCollection(), "zoom_in");
   m_pZoomIn->setWhatsThis(i18n("Click on this button to <b>zoom-in</b> on the selected region."));
 
@@ -159,35 +188,11 @@ void KmagApp::initActions()
   m_pZoomOut = KStdAction::zoomOut(this, SLOT(zoomOut()), actionCollection(), "zoom_out");
   m_pZoomOut->setWhatsThis(i18n("Click on this button to <b>zoom-out</b> on the selected region."));
 
-  // Help toolbar popup
-  KToolBarPopupAction *helpAction = new KToolBarPopupAction(i18n("&Help"), "help",
-                                          Key_F1, actionCollection(), "help_menu");
+  // KHelpMenu *newHelpMenu = new KHelpMenu(this, KGlobal::instance()->aboutData());
 
-  KHelpMenu *newHelpMenu = new KHelpMenu(this, KGlobal::instance()->aboutData());
-
-  helpAction->setDelayed(false);
-  KAction *action = KStdAction::helpContents(newHelpMenu, SLOT(appHelpActivated()), 0);
-  action->plug((QWidget*)helpAction->popupMenu());
-
-  action = KStdAction::reportBug(newHelpMenu, SLOT(reportBug()), 0);
-  action->plug((QWidget*)helpAction->popupMenu());
-
-  action = KStdAction::aboutApp(newHelpMenu, SLOT(aboutApplication()), 0);
-  action->plug((QWidget*)helpAction->popupMenu());
-
-  action = KStdAction::aboutKDE(newHelpMenu, SLOT(aboutKDE()), 0);
-  action->plug((QWidget*)helpAction->popupMenu());
-
-  // Settings tool bar popup
-  KToolBarPopupAction *confAction = new KToolBarPopupAction(i18n("&Settings"), "configure",
-                                          0, actionCollection(), "conf_menu");
-  confAction->setDelayed(false);
   m_keyConf = KStdAction::keyBindings( this, SLOT( slotConfKeys() ), actionCollection(), "key_conf");
-  m_keyConf->plug(confAction->popupMenu());
-
-  KAction *tbConf = KStdAction::configureToolbars( this, SLOT( slotEditToolbars() ),
+  m_toolConf = KStdAction::configureToolbars( this, SLOT( slotEditToolbars() ),
                                               actionCollection(), "toolbar_conf");
-  tbConf->plug(confAction->popupMenu());
 
   m_pFPSBox = new KSelectAction(i18n("&Refresh"),0,actionCollection(),"fps_selector");
   m_pFPSBox->setItems(fpsArrayString);
@@ -195,55 +200,16 @@ void KmagApp::initActions()
   m_pFPSBox->setToolTip(i18n("Refresh rate"));
 
   createGUI();
-
-  // we don't want a menu bar for this applications
-  menuBar()->hide();
 }
 
 void KmagApp::initView()
 {
-  QVBox *mainView = new QVBox(this);
-
-  m_zoomView = new KMagZoomView( mainView, "ZoomView" );
+  m_zoomView = new KMagZoomView( this, "ZoomView" );
   m_zoomView->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)7, (QSizePolicy::SizeType)7, m_zoomView->sizePolicy().hasHeightForWidth() ) );
   m_zoomView->setFrameShape( QFrame::StyledPanel );
   m_zoomView->setFrameShadow( QFrame::Raised );
 
-  m_settingsGroup = new QButtonGroup( mainView, "m_settingsGroup" );
-  m_settingsGroup->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)5, (QSizePolicy::SizeType)0, m_settingsGroup->sizePolicy().hasHeightForWidth() ) );
-  m_settingsGroup->setFrameShape( QButtonGroup::NoFrame );
-  m_settingsGroup->setTitle("");
-  m_settingsGroup->setColumnLayout(0, Qt::Vertical );
-  m_settingsGroup->layout()->setSpacing( 0 );
-  m_settingsGroup->layout()->setMargin( 0 );
-  QHBoxLayout *settingsGroupLayout = new QHBoxLayout( m_settingsGroup->layout() );
-  settingsGroupLayout->setAlignment( Qt::AlignTop );
-  settingsGroupLayout->setSpacing( 6 );
-  settingsGroupLayout->setMargin( 0 );
-
-  m_followMouseButton = new QCheckBox( m_settingsGroup, "m_followMouseButton" );
-  m_followMouseButton->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)1, (QSizePolicy::SizeType)1, m_followMouseButton->sizePolicy().hasHeightForWidth() ) );
-  m_followMouseButton->setText( i18n( "Follow mouse" ) );
-  QToolTip::add(m_followMouseButton, i18n("Magnify around the mouse cursor"));
-  QWhatsThis::add(m_followMouseButton, i18n("If selected, the area around the mouse cursor is magnified") );
-  settingsGroupLayout->addWidget( m_followMouseButton );
-  connect(m_followMouseButton, SIGNAL(toggled(bool)), m_zoomView, SLOT(followMouse(bool)));
-
-  m_showCursorButton = new QCheckBox( m_settingsGroup, "m_showCursorButton" );
-  m_showCursorButton->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)1, (QSizePolicy::SizeType)1, m_followMouseButton->sizePolicy().hasHeightForWidth() ) );
-  m_showCursorButton->setText( i18n( "Mouse cursor" ) );
-  QToolTip::add(m_showCursorButton, i18n("Show mouse cursor"));
-  settingsGroupLayout->addWidget( m_showCursorButton );
-  connect(m_showCursorButton, SIGNAL(toggled(bool)), this, SLOT(showMouseCursor(bool)));
-
-  m_showSelRectButton = new QCheckBox( m_settingsGroup, "m_showSelRectButton" );
-  m_showSelRectButton->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)1, (QSizePolicy::SizeType)1, m_showSelRectButton->sizePolicy().hasHeightForWidth() ) );
-  m_showSelRectButton->setText( i18n( "Selection window" ) );
-  QToolTip::add(m_showSelRectButton, i18n("Show the selection window on the screen"));
-  settingsGroupLayout->addWidget( m_showSelRectButton );
-  connect(m_showSelRectButton, SIGNAL(toggled(bool)), m_zoomView, SLOT(showSelRect(bool)));
-
-  setCentralWidget(mainView);
+  setCentralWidget(m_zoomView);
 }
 
 /**
@@ -278,7 +244,16 @@ void KmagApp::saveOptions()
   config->writeEntry("ShowSelRect", m_zoomView->getShowSelRect());
   config->writeEntry("ShowMouse", m_zoomView->getShowMouseType());
 
+  config->writeEntry("AlwaysFit", m_alwaysFit->isChecked());
+  
+  config->writeEntry("ShowMenu", m_pShowMenu->isChecked());
+  config->writeEntry("ShowMainToolBar", m_pShowMainToolBar->isChecked());
+  config->writeEntry("ShowViewToolBar", m_pShowViewToolBar->isChecked());
+  config->writeEntry("ShowSettingsToolBar", m_pShowSettingsToolBar->isChecked());
+
   toolBar("mainToolBar")->saveSettings(config,"Main ToolBar");
+  toolBar("viewToolBar")->saveSettings(config,"View ToolBar");
+  toolBar("settingsToolBar")->saveSettings(config,"Settings ToolBar");
 }
 
 
@@ -289,7 +264,7 @@ void KmagApp::readOptions()
 {
   config->setGroup("General Options");
 
-  QSize defSize(425,390);
+  QSize defSize(460,390);
   QSize size=config->readSizeEntry("Geometry", &defSize);
   if(!size.isEmpty())
   {
@@ -307,26 +282,49 @@ void KmagApp::readOptions()
 
   bool followMouse = config->readBoolEntry("FollowMouse", true);
   m_zoomView->followMouse(followMouse);
-  m_followMouseButton->setChecked(followMouse);
+  m_followMouse->setChecked(followMouse);
 
   QRect defaultRect(0,0,211,164);
   m_zoomView->setSelRectPos(config->readRectEntry("SelRect", &defaultRect));
 
   bool showSelRect = config->readBoolEntry("ShowSelRect", false);
   m_zoomView->showSelRect(showSelRect);
-  m_showSelRectButton->setChecked(showSelRect);
+  m_showSelRect->setChecked(showSelRect);
 
   m_mouseCursorType = config->readUnsignedNumEntry("ShowMouse", m_defaultMouseCursorType);
   m_zoomView->showMouse(m_mouseCursorType);
   if(m_mouseCursorType)
-    m_showCursorButton->setChecked(true);
+    m_hideCursor->setChecked(false);
   else
-    m_showCursorButton->setChecked(false);
+    m_hideCursor->setChecked(true);
+  
+  if(config->hasGroup("Settings ToolBar"))
+    toolBar("settingsToolBar")->applySettings(config,"Settings ToolBar");
+  else {
+    toolBar("settingsToolBar")->setIconText (KToolBar::IconTextRight);
+    toolBar("settingsToolBar")->setIconSize (16);
+  }
 
-  if(config->hasGroup("Main Toolbar"))
+  if(config->hasGroup("Main ToolBar"))
     toolBar("mainToolBar")->applySettings(config,"Main ToolBar");
-  else
-    toolBar("mainToolBar")->setBarPos(KToolBar::Bottom);
+
+  if(config->hasGroup("View ToolBar"))
+    toolBar("viewToolBar")->applySettings(config,"View ToolBar");
+
+  m_alwaysFit->setChecked(config->readBoolEntry("AlwaysFit", true));
+  slotAlwaysFit();
+
+  m_pShowMenu->setChecked(config->readBoolEntry("ShowMenu", true));
+  slotShowMenu();
+
+  m_pShowMainToolBar->setChecked(config->readBoolEntry("ShowMainToolBar", false));
+  slotShowMainToolBar();
+
+  m_pShowViewToolBar->setChecked(config->readBoolEntry("ShowViewToolBar", true));
+  slotShowViewToolBar();
+  
+  m_pShowSettingsToolBar->setChecked(config->readBoolEntry("ShowSettingsToolBar", true));
+  slotShowSettingsToolBar();
 }
 
 bool KmagApp::queryClose()
@@ -345,18 +343,14 @@ bool KmagApp::queryExit()
  *
  * @param e
  */
-void KmagApp::mousePressEvent(QMouseEvent *e)
+void KmagApp::contextMenuEvent ( QContextMenuEvent * e )
 {
-  kdDebug() << "Got a press event!" << endl;
-
-  switch(e->button()) {
-  case QMouseEvent::RightButton :
-    // show popup
-    kdDebug() << "Show Popup now!" << endl;
-    break;
-  default :
-    break;
-  }
+ // show popup
+ KXMLGUIFactory *factory = this->factory();
+ QPopupMenu *popup = (QPopupMenu *)factory->container("mainPopUp",this);
+ if (popup != 0)
+   popup->popup(e->globalPos(), 0);
+ e->accept();
 }
 
 
@@ -485,7 +479,7 @@ void KmagApp::saveZoomPixmap()
           KMessageBox::error(0, i18n("Unable to upload file over the network."),
                             i18n("Error Writing File"));
         } else {
-          KMessageBox::information(0, i18n("Current zoomed image saved to\n")+url.prettyURL(),
+          KMessageBox::information(0, i18n("Current zoomed image saved to\n%1").arg(url.prettyURL()),
                               i18n("Information"), "save_confirm");
         }
       }
@@ -497,7 +491,7 @@ void KmagApp::saveZoomPixmap()
         KMessageBox::error(0, i18n("Unable to save file. Please check if you have permission to write to the directory."),
                             i18n("Error Writing File"));
       } else {
-        KMessageBox::information(0, i18n("Current zoomed image saved to\n")+url.prettyURL(),
+        KMessageBox::information(0, i18n("Current zoomed image saved to\n%1").arg(url.prettyURL()),
                                 i18n("Information"), "save_confirm");
       }
     }
@@ -522,6 +516,21 @@ void KmagApp::slotToggleRefresh()
   }
 }
 
+void KmagApp::slotToggleFollowMouse()
+{
+  m_zoomView->followMouse(m_followMouse->isChecked());
+}
+
+void KmagApp::slotToggleHideCursor()
+{
+  showMouseCursor(!m_hideCursor->isChecked());
+}
+
+void KmagApp::slotToggleShowSelRect()
+{
+  m_zoomView->showSelRect(m_showSelRect->isChecked());
+}
+
 
 void KmagApp::slotFileNewWindow()
 {
@@ -576,17 +585,58 @@ void KmagApp::slotFilePrint()
 #endif // QT_NO_PRINTER
 }
 
+void KmagApp::slotFileQuit()
+{
+  saveOptions();
+  // close the first window, the list makes the next one the first again.
+  // This ensures that queryClose() is called on each window to ask for closing
+  KMainWindow* w;
+  if (memberList)
+  {
+    for(w=memberList->first(); w!=0; w=memberList->first())
+    {
+      // only close the window if the closeEvent is accepted. If the user presses Cancel on the saveModified() dialog,
+      // the window and the application stay open.
+      if(!w->close())
+         break;
+      memberList->removeRef(w);
+    }
+  }	
+}
+
 void KmagApp::copyToClipBoard()
 {
   QClipboard *cb=KApplication::clipboard();
   cb->setPixmap(m_zoomView->getPixmap());
 }
 
-void KmagApp::slotViewToolBar()
+void KmagApp::slotAlwaysFit()
+{
+  m_zoomView->setFitToWindow (m_alwaysFit->isChecked());
+  m_fitToWindow->setEnabled (!m_alwaysFit->isChecked());
+}
+
+void KmagApp::slotShowMenu()
 {
   ///////////////////////////////////////////////////////////////////
-  // turn Toolbar on or off
-  if(!viewToolBar->isChecked())
+  // turn Menu on or off
+  if(!m_pShowMenu->isChecked())
+  {
+    menuBar()->hide();
+  }
+  else
+  {
+    menuBar()->show();
+  }
+
+  
+}
+
+void KmagApp::slotShowMainToolBar()
+{
+  ///////////////////////////////////////////////////////////////////
+  // turn mainToolbar on or off
+  if(!m_pShowMainToolBar->isChecked())
   {
     toolBar("mainToolBar")->hide();
   }
@@ -596,6 +646,34 @@ void KmagApp::slotViewToolBar()
   }
 }
 
+void KmagApp::slotShowViewToolBar()
+{
+  ///////////////////////////////////////////////////////////////////
+  // turn viewToolbar on or off
+  if(!m_pShowViewToolBar->isChecked())
+  {
+    toolBar("viewToolBar")->hide();
+  }
+  else
+  {
+    toolBar("viewToolBar")->show();
+  }
+}
+
+void KmagApp::slotShowSettingsToolBar()
+{
+  ///////////////////////////////////////////////////////////////////
+  // turn viewToolbar on or off
+  if(!m_pShowSettingsToolBar->isChecked())
+  {
+    toolBar("settingsToolBar")->hide();
+  }
+  else
+  {
+    toolBar("settingsToolBar")->show();
+  }
+}
+
 void KmagApp::slotConfKeys()
 {
   KKeyDialog::configureKeys( actionCollection(), xmlFile() );
