@@ -1,10 +1,11 @@
-//$Id: kmagzoomview.cpp,v 1.26 2003/03/15 06:08:31 sarang Exp $
 /***************************************************************************
                           kmagview.cpp  -  description
                              -------------------
     begin                : Mon Feb 12 23:45:41 EST 2001
     copyright            : (C) 2001-2003 by Sarang Lakare
     email                : sarang#users.sourceforge.net
+    copyright            : (C) 2003 by Olaf Schmidt
+    email                : ojschmidt@kde.org
  ***************************************************************************/
 
 /***************************************************************************
@@ -74,7 +75,7 @@ static uchar phand_bits[] = {
 
 KMagZoomView::KMagZoomView(QWidget *parent, const char *name)
   : QFrame(parent, name),
-    m_selRect(0, 0, 128, 128),
+    m_selRect(0, 0, 128, 128, this),
     m_grabTimer(parent),
     m_mouseViewTimer(parent),
     m_latestCursorPos(0,0),
@@ -87,7 +88,7 @@ KMagZoomView::KMagZoomView(QWidget *parent, const char *name)
   setMouseTracking(TRUE);
   setFrameStyle(QFrame::WinPanel | QFrame::Sunken);
   setLineWidth(0);
-  setBackgroundColor(QColor("grey"));
+  setBackgroundMode (NoBackground);
   setFocusPolicy(QWidget::StrongFocus);
   
   // init the zoom matrix
@@ -169,6 +170,14 @@ void KMagZoomView::showEvent( QShowEvent* )
   }
 }
 
+/**
+ * Called when the widget is resized. Check if fitToWindow is active when this happens.
+ */
+void KMagZoomView::resizeEvent(QResizeEvent* )
+{
+  if(m_fitToWindow)
+    fitToWindow(); 
+}
 
 /**
  * Called when the widget is to be repainted
@@ -180,12 +189,12 @@ void KMagZoomView::paintEvent(QPaintEvent* )
   if(m_grabbedZoomedPixmap.isNull())
     return;
   // paint on this widget
-  paintViewImage(this);
+  paintViewImage(this, m_refreshSwitch);
 }
 
 /**
  * This function will actually draw on the paintdevice the
- * final output. This is seperated from paintEvent for printing purposes.
+ * final output. This is separated from paintEvent for printing purposes.
  */
 void KMagZoomView::paintViewImage(QPaintDevice *dev, bool updateMousePos)
 {
@@ -195,12 +204,20 @@ void KMagZoomView::paintViewImage(QPaintDevice *dev, bool updateMousePos)
   // get a rectangle centered inside the frame
   QRect pRect(pixmapRect());
 
-  // get rectangular area that needs to be repainted
-  //QRect uRect(e->rect());
-
   // get the rectangle inside the frame
   QRect wRect(contentsRect());
 
+  // Paint empty areas black
+  QPainter pa (dev);
+  if (pRect.x() > 0) {
+    pa.fillRect (0,0,pRect.x(),wRect.height(), Qt::black);
+    pa.fillRect (pRect.x()+pRect.width(),0,wRect.width()-pRect.width()-pRect.x(),wRect.height(), Qt::black);
+  }
+  if (pRect.y() > 0) {
+    pa.fillRect (0,0,wRect.width(),pRect.y(), Qt::black);
+    pa.fillRect (0,pRect.y()+pRect.height(),wRect.width(),wRect.height()-pRect.height()-pRect.y(), Qt::black);
+  }
+
   // A pixmap which will be eventually displayed
   QPixmap *zoomView;
 
@@ -219,93 +236,48 @@ void KMagZoomView::paintViewImage(QPaintDevice *dev, bool updateMousePos)
     zoomView = &m_grabbedZoomedPixmap;
   }
 
-  if(m_grabbedZoomedPixmap.width() < wRect.width() &&
-     m_grabbedZoomedPixmap.height() < wRect.height()) {
-    // zoomed image is smaller than the display area
-    // there is a need to clear the window first
-    // a paint area that is to be painted on
-    QPixmap paintArea(wRect.size());
-    QPainter pa(&paintArea);
+  int width = m_grabbedZoomedPixmap.width();
+  int height = m_grabbedZoomedPixmap.height();
+  int xdiff = width - wRect.width();
+  int ydiff = height - wRect.height();
 
-    pa.setBackgroundColor(Qt::black);
-  
-    // clear the paint area
-    pa.eraseRect(paintArea.rect());
+  // set the (x,y) of start of the part of zoom image to display
+  // and the w,h of the part to display
+  if(xdiff >= 0) {
+    // center the shown part of image to the mouse position
+    xdiff = mousePos.x() - (int)(wRect.width()/2.0);
+    // Is the mouse at the border of the part?
+    if (xdiff < 0)
+      xdiff = 0;
+    else if (xdiff + wRect.width() > width)
+      xdiff = width - wRect.width();
 
-    // draw the pixmap on the paint area
-    bitBlt(&paintArea, pRect.x(), pRect.y(), zoomView);
+    width = wRect.width();
+  }
+  else
+    xdiff = 0;
 
-    // bitBlt the paintArea pixmap on the widget  
-    bitBlt(dev, QPoint(0,0), &paintArea);
-  } else {
-    int width = m_grabbedZoomedPixmap.width();
-    int height = m_grabbedZoomedPixmap.height();
-    int xdiff = width - wRect.width();
-    int ydiff = height - wRect.height();
+  if(ydiff >= 0) {
+    // center the shown part of image to the mouse position
+    ydiff = mousePos.y() - (int)(wRect.height()/2.0);
+    // Is the mouse at the border of the part?
+    if (ydiff < 0)
+      ydiff = 0;
+    else if (ydiff + wRect.height() > height)
+      ydiff = height - wRect.height();
 
-    // set the (x,y) of start of the part of zoom image to display
-    // and the w,h of the part to display
-    if(xdiff >= 0) {
-      // center the shown part of image to the mouse position
-      xdiff = mousePos.x() - (int)(wRect.width()/2.0);
-      // Is the mouse at the border of the part?
-      if (xdiff < 0)
-        xdiff = 0;
-      else if (xdiff + wRect.width() > width)
-        xdiff = width - wRect.width();
+    height = wRect.height();
+  }
+  else
+    ydiff = 0;
 
-      width = wRect.width();
-    }
+  // The rect corr. to the part of zoom view whish should be shown
+  QRect srcRect(xdiff, ydiff, width, height);
 
-    if(ydiff >= 0) {
-      // center the shown part of image to the mouse position
-      ydiff = mousePos.y() - (int)(wRect.height()/2.0);
-      // Is the mouse at the border of the part?
-      if (ydiff < 0)
-        ydiff = 0;
-      else if (ydiff + wRect.height() > height)
-        ydiff = height - wRect.height();
+  // bitBlt this part on to the widget.
+  bitBlt(dev, QPoint(pRect.x(), pRect.y()), zoomView, srcRect);
 
-      height = wRect.height();
-    }
-
-    if(xdiff < 0 || ydiff < 0) {
-      // only one of the sides is larger than the display area
-      if(xdiff < 0)
-        xdiff = 0;
-      else
-        ydiff = 0;
-
-      // there is a need to clear the window first
-      // a paint area that is to be painted on
-      QPixmap paintArea(wRect.size());
-      QPainter pa(&paintArea);
-
-      pa.setBackgroundColor(Qt::black);
-    
-      // clear the paint area
-      pa.eraseRect(paintArea.rect());
-
-      // The rect corr. to the part of zoom view whish should be shown
-      QRect srcRect(xdiff, ydiff, width, height);
-
-      // bitBlt zoom view onto the paint area
-      bitBlt(&paintArea, QPoint(pRect.x(), pRect.y()), zoomView, srcRect);
-
-      // bitBlt the paintArea pixmap on the widget  
-      bitBlt(dev, QPoint(0,0), &paintArea);
-    } else { // the zoom image is larger than the display    
-      // The rect corr. to the part of zoom view whish should be shown
-      QRect srcRect(xdiff, ydiff, width, height);
-
-      // bitBlt this part on to the widget.
-      bitBlt(dev, QPoint(0,0), zoomView, srcRect);
-    } //if(xdiff < 0 || ydiff < 0)
-
-  } //if-else(xdiff < 0 && ydiff <0)   
-
-
-  if(zoomView != &m_grabbedZoomedPixmap)  
+  if(zoomView != &m_grabbedZoomedPixmap)
     delete zoomView;
 }
 
@@ -345,7 +317,7 @@ void KMagZoomView::paintMouseCursor(QPaintDevice *dev, QPoint mousePos)
       QBitmap mask( 16, 16, left_ptrmsk_bits, TRUE );
       sCursor.setMask(mask);
       sCursor = sCursor.xForm(m_zoomMatrix);
-                
+
       // since hot spot is at 3,1
       pz.drawPixmap(mousePos.x()-(int)(3.0*m_zoom), mousePos.y()-(int)m_zoom, sCursor);
     }
@@ -370,7 +342,7 @@ void KMagZoomView::paintMouseCursor(QPaintDevice *dev, QPoint mousePos)
           QBitmap mask( 16, 16, left_ptrmsk_bits, TRUE );
           sCursor.setMask(mask);
           sCursor = sCursor.xForm(m_zoomMatrix);
-                    
+
           // since hot spot is at 3,1
           pz.drawPixmap(mousePos.x()-(int)(3.0*m_zoom), mousePos.y()-(int)m_zoom, sCursor);
         }
@@ -379,7 +351,7 @@ void KMagZoomView::paintMouseCursor(QPaintDevice *dev, QPoint mousePos)
           QBitmap sCursor( 32, 32, phand_bits, TRUE );
           QBitmap mask( 32, 32, phandm_bits, TRUE );
           sCursor.setMask(mask);
-                    
+
           pz.drawPixmap(mousePos.x(), mousePos.y(), sCursor);
         break;
       } // switch(cursor)
@@ -435,20 +407,12 @@ QRect KMagZoomView::pixmapRect()
  */
 void KMagZoomView::mousePressEvent(QMouseEvent *e)
 {
-  // don't do anything if follow mouse is enabled
-  if(m_followMouse) {
-#if QT_VERSION >= 300
-    // ignore this button press.. so it goes to the parent
-    e->ignore();
-#endif
-    return;
-  }
-
   switch(e->button()) {
   case QMouseEvent::LeftButton :
     if(m_ctrlKeyPressed) {
       // check if currently in resize mode
-      if(m_mouseMode != ResizeSelection) {
+      // don't do anything if fitToWindow is enabled
+      if ((m_mouseMode != ResizeSelection) && !m_fitToWindow) {
         // set the mode to ResizeSelection
         m_mouseMode = ResizeSelection;
 
@@ -465,9 +429,16 @@ void KMagZoomView::mousePressEvent(QMouseEvent *e)
         // show the selection rectangle
         m_selRect.show();
       }
+      else {
+        #if QT_VERSION >= 300
+        // ignore this button press.. so it goes to the parent
+        e->ignore();
+        #endif
+      }
     } else if(m_shiftKeyPressed) {
       // check if currently in move mode
-      if(m_mouseMode != MoveSelection) {
+      // don't do anything if follow mouse is enabled
+      if ((m_mouseMode != MoveSelection) && !m_followMouse) {
         m_mouseMode = MoveSelection;
 
         // set mouse cursor to cross hair
@@ -483,9 +454,16 @@ void KMagZoomView::mousePressEvent(QMouseEvent *e)
         // show the selected rectangle
         m_selRect.show();
       }
+      else {
+        #if QT_VERSION >= 300
+        // ignore this button press.. so it goes to the parent
+        e->ignore();
+        #endif
+      }
     } else {
       // check if currently in move mode
-      if(m_mouseMode != GrabSelection) {
+      // don't do anything if follow mouse is enabled
+      if ((m_mouseMode != GrabSelection) && !m_followMouse) {
         m_mouseMode = GrabSelection;
 
         // set mouse cursor to hand
@@ -500,12 +478,19 @@ void KMagZoomView::mousePressEvent(QMouseEvent *e)
         // show the selected rectangle
         m_selRect.show();
       }
+      else {
+        #if QT_VERSION >= 300
+        // ignore this button press.. so it goes to the parent
+        e->ignore();
+        #endif
+      }
     }
     break;
 
   case QMouseEvent::MidButton :
-        // check if currently in move mode
-    if(m_mouseMode != MoveSelection) {
+    // check if currently in move mode
+    // don't do anything if follow mouse is enabled
+    if ((m_mouseMode != MoveSelection) && !m_followMouse) {
       m_mouseMode = MoveSelection;
 
       // set mouse cursor to cross hair
@@ -521,6 +506,12 @@ void KMagZoomView::mousePressEvent(QMouseEvent *e)
       // show the selected rectangle
       m_selRect.show();
     }
+    else {
+      #if QT_VERSION >= 300
+      // ignore this button press.. so it goes to the parent
+      e->ignore();
+      #endif
+    }
     break;
   // do nothing
   default:
@@ -540,10 +531,6 @@ void KMagZoomView::mousePressEvent(QMouseEvent *e)
  */
 void KMagZoomView::mouseReleaseEvent(QMouseEvent *e)
 {
-  // don't do anything if follow mouse is enabled
-  if(m_followMouse)
-    return;
-
   switch(e->button()) {
   case QMouseEvent::LeftButton :
   case QMouseEvent::MidButton :
@@ -601,17 +588,12 @@ void KMagZoomView::mouseReleaseEvent(QMouseEvent *e)
  */
 void KMagZoomView::mouseMoveEvent(QMouseEvent *e)
 {
-  // don't do anything if follow mouse is enabled
-  if(m_followMouse) {
-    grabFrame();
-  } else if(m_mouseMode == ResizeSelection) {
+  if(m_mouseMode == ResizeSelection) {
     // In resize selection mode
     // set the current mouse position as the bottom, right corner
     m_selRect.setRight(e->globalX());
     m_selRect.setBottom(e->globalY());
     m_selRect.update();
-    // since the selection window has been resized, set fitToWindow to false
-    m_fitToWindow = false;
     grabFrame();
   } else if(m_mouseMode == MoveSelection) {
      QPoint newCenter;
@@ -743,17 +725,29 @@ void KMagZoomView::fitToWindow()
   m_selRect.moveCenter(currCenter);
   // update the grab rectangle display
   m_selRect.update();
-  m_fitToWindow = true;
+//  m_fitToWindow = true;
   repaint(false);
 }
 
+void KMagZoomView::setFitToWindow(bool fit)
+{
+  m_fitToWindow = fit;
+  if (fit)
+    fitToWindow();
+}
+
+
 /**
  * Grabs frame from X
  */
 void KMagZoomView::grabFrame()
 {
+  // check refresh status
+  if (!m_refreshSwitch)
+     return;
+
   // check if follow-mouse is enabled
-  if(m_followMouse) {
+  if(m_followMouse && (m_mouseMode != ResizeSelection)) {
     // in this case grab w.r.t the current mouse position
      QPoint newCenter;
 
@@ -776,10 +770,12 @@ void KMagZoomView::grabFrame()
     } else if(newCenter.y() >=  QApplication::desktop()->height()-m_selRect.height()/2) {
       // set Y to the maximum possible Y
       newCenter.setY(QApplication::desktop()->height()-m_selRect.height()/2-1);
-    }              
+    }
     // move to the new center
     m_selRect.moveCenter(newCenter);
 
+    // update the grab rectangle display
+    m_selRect.update();
   }
 
   //QRect r = pixmapRect();
@@ -796,9 +792,6 @@ void KMagZoomView::grabFrame()
 
   // call repaint to display the newly grabbed image
   repaint(false);
-
-  // update the grab rectangle display
-  m_selRect.update();
 }
 
 
@@ -838,12 +831,16 @@ void KMagZoomView::setZoom(float zoom)
   // use this zoom
   m_zoom = zoom;
 
+  // update selection window size when zooming in if necessary
+  if (m_fitToWindow)
+    fitToWindow();
+
   // recompute the zoom matrix
   m_zoomMatrix.reset();
-  m_zoomMatrix.scale(m_zoom, m_zoom);  
-   
+  m_zoomMatrix.scale(m_zoom, m_zoom);
+
   m_grabbedZoomedPixmap = m_grabbedPixmap.xForm(m_zoomMatrix);
-  
+
   repaint();
 }
 
