@@ -1,5 +1,3 @@
-//$Id: main.cpp,v 1.13 2003/03/15 05:58:21 sarang Exp $
-
 /***************************************************************************
                           main.cpp  -  description
                              -------------------
@@ -37,46 +35,48 @@ KmagApp *kmagapp;
 static KCmdLineOptions options[] =
 {
   { "+[File]", I18N_NOOP("File to open"), 0 },
-  { 0, 0, 0 }
+  KCmdLineLastOption
   // INSERT YOUR COMMANDLINE OPTIONS HERE
 };
 
 int main(int argc, char *argv[])
 {
   // about the application
-  KAboutData *aboutData = new KAboutData("kmag", I18N_NOOP("K Magnifier"), KMAG_VERSION,
-                                         I18N_NOOP("Screen Magnifier for the K Desktop Environment (KDE)"),
+  KAboutData *aboutData = new KAboutData("kmag", I18N_NOOP("KMagnifier"), KMAG_VERSION,
+                                         I18N_NOOP("Screen magnifier for the K Desktop Environment (KDE)"),
                                          KAboutData::License_GPL,
                                          "(C) 2001-2003, Sarang Lakare","",
                                          "http://kmag.sourceforge.net");
 
   // about the authors
   aboutData->addAuthor("Sarang Lakare",
-                       I18N_NOOP("ReWrite + Current Maintainer"),"sarang@users.sf.net",
+                       I18N_NOOP("Rewrite and current maintainer"),"sarang@users.sf.net",
                        "http://www.cs.sunysb.edu/~lsarang/linux");
   aboutData->addAuthor("Michael Forster",
-                       I18N_NOOP("Original Idea & Author (KDE1)"), "forster@fmi.uni-passau.de");
-  aboutData->addCredit("Claudiu Costin", I18N_NOOP("Tips, competition ;)"), "claudiuc@work.ro",
+                       I18N_NOOP("Original idea and author (KDE1)"), "forster@fmi.uni-passau.de");
+
+  aboutData->addCredit("Olaf Schmidt", I18N_NOOP("Various patches"), "ojschmidt@kde.org");
+  aboutData->addCredit("Claudiu Costin", I18N_NOOP("Some tips"), "claudiuc@work.ro",
                        "http://www.ro.kde.org");
 
   KCmdLineArgs::init( argc, argv, aboutData );
   KCmdLineArgs::addCmdLineOptions( options ); // Add our own options.
 
   KApplication app;
- 
+
   if (app.isRestored())
   {
     RESTORE(KmagApp);
   }
-  else 
+  else
   {
     kmagapp = new KmagApp();
     kmagapp->show();
 
     KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
-    
+
     args->clear();
   }
 
   return app.exec();
-}  
+}
