@@ -15,8 +15,6 @@
  *                                                                         *
  ***************************************************************************/
 
-// $Id: kmouth.cpp,v 1.7 2003/03/17 22:57:48 mueller Exp $
-
 // include files for QT
 #include <qdir.h>
 #include <qpainter.h>
@@ -55,6 +53,8 @@ KMouthApp::KMouthApp(QWidget* , const char* name):KMainWindow(0, name)
    optionsDialog = new OptionsDialog(this);
    connect (optionsDialog, SIGNAL(configurationChanged ()),
             this, SLOT(slotConfigurationChanged ()));
+   connect (optionsDialog, SIGNAL(configurationChanged ()),
+            phraseList, SLOT(configureCompletion ()));
 
    phrases = new KActionCollection (this);
 
@@ -74,6 +74,10 @@ KMouthApp::KMouthApp(QWidget* , const char* name):KMainWindow(0, name)
       isConfigured = true;
    delete wizard;
 
+   if (isConfigured) {
+      phraseList->configureCompletion();
+   }
+
    ///////////////////////////////////////////////////////////////////
    // disable actions at startup
    fileSaveAs->setEnabled(false);
@@ -91,15 +95,15 @@ bool KMouthApp::configured() {
 
 void KMouthApp::initActions() {
 // The "File" menu
-   fileOpen = new KAction(i18n("&Open as History..."), "phrasehistory_open", KShortcut("Ctrl+O"), this, SLOT(slotFileOpen()), actionCollection(),"file_open");
+   fileOpen = new KAction(i18n("&Open as History..."), "phrasehistory_open", KStdAccel::key(KStdAccel::Open), this, SLOT(slotFileOpen()), actionCollection(),"file_open");
    fileOpen->setStatusText(i18n("Opens an existing file as history"));
    fileOpen->setWhatsThis (i18n("Opens an existing file as history"));
 
-   fileSaveAs = new KAction(i18n("&Save History As..."), "phrasehistory_save", KShortcut("Ctrl+S"), this, SLOT(slotFileSaveAs()), actionCollection(),"file_save_as");
+   fileSaveAs = new KAction(i18n("Save &History As..."), "phrasehistory_save", KStdAccel::key(KStdAccel::Save), this, SLOT(slotFileSaveAs()), actionCollection(),"file_save_as");
    fileSaveAs->setStatusText(i18n("Saves the actual history as..."));
    fileSaveAs->setWhatsThis (i18n("Saves the actual history as..."));
 
-   filePrint = new KAction(i18n("&Print History..."), "phrasehistory_print", KShortcut("Ctrl+P"), this, SLOT(slotFilePrint()), actionCollection(),"file_print");
+   filePrint = new KAction(i18n("&Print History..."), "phrasehistory_print", KStdAccel::key(KStdAccel::Print), this, SLOT(slotFilePrint()), actionCollection(),"file_print");
    filePrint->setStatusText(i18n("Prints out the actual history"));
    filePrint->setWhatsThis (i18n("Prints out the actual history"));
 
@@ -152,7 +156,7 @@ void KMouthApp::initActions() {
    phraseListRemove->setStatusText(i18n("Removes the currently selected phrases from the history"));
    phraseListRemove->setWhatsThis (i18n("Removes the currently selected phrases from the history"));
 
-   phraseListCut = new KAction (i18n("&Cut"),   "editcut", 0, phraseList, SLOT(cutListSelection()),    actionCollection(), "phraselist_cut");
+   phraseListCut = new KAction (i18n("Cu&t"),   "editcut", 0, phraseList, SLOT(cutListSelection()),    actionCollection(), "phraselist_cut");
    phraseListCut->setStatusText(i18n("Cuts the currently selected phrases from the history and puts them to the clipboard"));
    phraseListCut->setWhatsThis (i18n("Cuts the currently selected phrases from the history and puts them to the clipboard"));
 
@@ -160,7 +164,7 @@ void KMouthApp::initActions() {
    phraseListCut->setStatusText(i18n("Copies the currently selected phrases from the history to the clipboard"));
    phraseListCut->setWhatsThis (i18n("Copies the currently selected phrases from the history to the clipboard"));
 
-   phraselistSelectAll = new KAction (i18n("&Select All Entries"), 0, 0, phraseList, SLOT(selectAllEntries()), actionCollection(),"phraselist_select_all");
+   phraselistSelectAll = new KAction (i18n("Select &All Entries"), 0, 0, phraseList, SLOT(selectAllEntries()), actionCollection(),"phraselist_select_all");
    phraselistSelectAll->setStatusText(i18n("Selects all phrases in the history"));
    phraselistSelectAll->setWhatsThis (i18n("Selects all phrases in the history"));
 
@@ -189,8 +193,8 @@ void KMouthApp::initPhraseList()
   // create the main widget here that is managed by KTMainWindow's view-region and
   // connect the widget to your document to display document contents.
 
-  phraseList = new PhraseList(this);
-  setCentralWidget(phraseList);
+   phraseList = new PhraseList(this);
+   setCentralWidget(phraseList);
 }
 
 void KMouthApp::openDocumentFile(const KURL& url)
@@ -209,6 +213,8 @@ void KMouthApp::saveOptions() {
       config->writeEntry("Show Statusbar",viewStatusBar->isChecked());
       config->writeEntry("ToolBarPos", (int) toolBar("mainToolBar")->barPos());
 
+      if (phraseList != 0)
+         phraseList->saveCompletionOptions(config);
       optionsDialog->saveOptions(config);
       toolBar("mainToolBar")->saveSettings (config, "mainToolBar");
       toolBar("phrasebookBar")->saveSettings (config, "phrasebookBar");
@@ -252,6 +258,8 @@ void KMouthApp::readOptions()
      book.open(standardBook);
      slotPhrasebookConfirmed(book);
   }
+  if (phraseList != 0)
+     phraseList->readCompletionOptions(config);
 }
 
 bool KMouthApp::queryClose()
@@ -382,6 +390,7 @@ void KMouthApp::slotViewStatusBar()
 }
 
 void KMouthApp::slotConfigureTTS() {
+   phraseList->saveWordCompletion();
    optionsDialog->show();
 }
 
