@@ -15,8 +15,6 @@
  *                                                                         *
  ***************************************************************************/
 
-// $Id: phrasebookdialog.cpp,v 1.8 2003/03/07 10:07:21 gunnar Exp $
-
 // include files for QT
 #include <qapplication.h>
 #include <qlayout.h>
@@ -274,7 +272,7 @@ PhraseBookDialog::PhraseBookDialog ()
       currentChanged(treeView->currentItem());
       phrasebookChanged = false;
    }
-   // i18n("Edit phrase book")
+   // i18n("Edit Phrase Book")
 }
 
 PhraseBookDialog *PhraseBookDialog::get() {
@@ -341,7 +339,7 @@ void PhraseBookDialog::initActions() {
    toolbarImport->setStatusText(i18n("Imports a file and adds its contents to the phrase book"));
    toolbarImport->setWhatsThis (i18n("Imports a file and adds its contents to the phrase book"));
 
-   fileImportStandardBook = new KActionMenu (i18n("Import &Standard Phrase Book"), "phrasebook_open", actionCollection(),"file_import_standard_book");
+   fileImportStandardBook = new KActionMenu (i18n("I&mport Standard Phrase Book"), "phrasebook_open", actionCollection(),"file_import_standard_book");
    fileImportStandardBook->setStatusText(i18n("Imports a standard phrase book and adds its contents to the phrase book"));
    fileImportStandardBook->setWhatsThis (i18n("Imports a standard phrase book and adds its contents to the phrase book"));
 
@@ -525,11 +523,10 @@ void PhraseBookDialog::currentChanged (QListViewItem *item) {
 
 bool PhraseBookDialog::queryClose() {
    if (phrasebookChanged) {
-      KGuiItem no = KGuiItem (i18n("Do &not save"));
       int answer = KMessageBox::questionYesNoCancel (this,
-          i18n("Do you want to save the changes of the phrase book?"),
-          i18n("Closing the \"Phrase book\" window"),
-          KStdGuiItem::yes(), no, "AutomaticSave");
+          i18n("There are unsaved changes.<br>Do you want to apply the changes before closing the \"phrase book\" window or discard the changes?"),
+          i18n("Closing \"Phrase Book\" Window"),
+          KStdGuiItem::apply(), KStdGuiItem::discard(), "AutomaticSave");
       if (answer == KMessageBox::Yes) {
          slotSave();
          return true;
@@ -722,7 +719,7 @@ void PhraseBookDialog::slotExportPhrasebook () {
    treeView->fillBook (&book, treeView->hasSelectedItems());
    
    KURL url;
-   if (book.save (this, i18n("Export Phrase Book"), url) == -1);
+   if (book.save (this, i18n("Export Phrase Book"), url) == -1)
       KMessageBox::sorry(this,i18n("There was an error saving file\n%1").arg( url.url() ));
 }
 
