@@ -15,8 +15,6 @@
  *                                                                         *
  ***************************************************************************/
 
-// $Id: phraselist.cpp,v 1.4 2003/03/17 22:57:48 mueller Exp $
-
 // include files for Qt
 #include <qprinter.h>
 #include <qpainter.h>
@@ -33,6 +31,7 @@
 #include <kiconloader.h>
 #include <klocale.h>
 #include <kfiledialog.h>
+#include <kcombobox.h>
 #include <kmessagebox.h>
 
 #include <stdlib.h>
@@ -44,8 +43,9 @@
 #include "kmouth.h"
 #include "texttospeechsystem.h"
 #include "phrasebook/phrasebook.h"
+#include "wordcompletion/wordcompletion.h"
 
-PhraseList::PhraseList(QWidget *parent, const char *name ) : QWidget(parent,name) {
+PhraseList::PhraseList(QWidget *parent, const char *name) : QWidget(parent,name) {
    isInSlot = false;
    setBackgroundMode(PaletteBase);
    QVBoxLayout *layout = new QVBoxLayout (this);
@@ -59,10 +59,18 @@ PhraseList::PhraseList(QWidget *parent, const char *name ) : QWidget(parent,name
    QHBoxLayout *rowLayout = new QHBoxLayout ();
    layout->addLayout(rowLayout);
 
+   completion = new WordCompletion();
+
+   dictionaryCombo = new KComboBox (this, "Dictionary Combo");
+   configureCompletionCombo(completion->wordLists());
+   rowLayout->addWidget(dictionaryCombo);
+
    lineEdit = new PhraseEdit ("", this);
    lineEdit->setFocusPolicy(QWidget::StrongFocus);
    lineEdit->setFrame(true);
    lineEdit->setEchoMode(QLineEdit::Normal);
+   lineEdit->setCompletionObject (completion);
+   lineEdit->setAutoDeleteCompletionObject(true);
    QWhatsThis::add (lineEdit, i18n("Into this edit field you can type a phrase. Click on the speak button in order to speak the entered phrase."));
    rowLayout->addWidget(lineEdit);
 
@@ -73,6 +81,8 @@ PhraseList::PhraseList(QWidget *parent, const char *name ) : QWidget(parent,name
    QWhatsThis::add (speakButton, i18n("Speaks the currently active sentence(s). If there is some text in the edit field it is spoken. Otherwise the selected sentences in the history (if any) are spoken."));
    rowLayout->addWidget(speakButton);
 
+   connect(dictionaryCombo, SIGNAL (activated (const QString &)), completion, SLOT (setWordList(const QString &)));
+   connect(completion, SIGNAL (wordListsChanged (const QStringList &)), this, SLOT (configureCompletionCombo (const QStringList &)));
    connect(listBox,  SIGNAL(selectionChanged()), SLOT(selectionChanged()));
    connect(listBox,  SIGNAL(contextMenuRequested (QListBoxItem *, const QPoint &)), SLOT(contextMenuRequested (QListBoxItem *, const QPoint &)));
    connect(lineEdit, SIGNAL(returnPressed(const QString &)), SLOT(lineEntered(const QString &)));
@@ -132,9 +142,63 @@ void PhraseList::enableMenuEntries() {
    theApp->enableMenuEntries (selected, deselected);
 }
 
+void PhraseList::configureCompletion() {
+   completion->configure();
+}
+
+void PhraseList::configureCompletionCombo(const QStringList &list) {
+   QString current = completion->currentWordList();
+   dictionaryCombo->clear();
+   if (list.isEmpty())
+      dictionaryCombo->hide();
+   else {
+      dictionaryCombo->insertStringList (list);
+      dictionaryCombo->show();
+   
+      QStringList::ConstIterator it;
+      int i = 0;
+      for (it = list.begin(), i = 0; it != list.end(); ++it, ++i) {
+         if (current == *it) {
+            dictionaryCombo->setCurrentItem (i);
+            return;
+         }
+      }
+   }
+}
+void PhraseList::saveCompletionOptions(KConfig *config) {
+      config->setGroup("Completion");
+      config->writeEntry("Mode", static_cast<int>(lineEdit->completionMode()));
+      config->writeEntry("List", completion->currentWordList());
+}
+
+void PhraseList::readCompletionOptions(KConfig *config) {
+   if (config->hasGroup ("Completion")) {
+      config->setGroup("Completion");
+      int mode = config->readNumEntry ("Mode", KGlobalSettings::completionMode());
+      lineEdit->setCompletionMode (static_cast<KGlobalSettings::Completion>(mode));
+
+      QString current = config->readEntry ("List", QString::null);
+      QStringList list = completion->wordLists();
+      QStringList::ConstIterator it;
+      int i = 0;
+      for (it = list.begin(), i = 0; it != list.end(); ++it, ++i) {
+         if (current == *it) {
+            dictionaryCombo->setCurrentItem (i);
+            return;
+         }
+      }
+   }
+}
+
+void PhraseList::saveWordCompletion () {
+   completion->save();
+}
+
+
 void PhraseList::selectAllEntries () {
    listBox->selectAll (true);
 }
+
 void PhraseList::deselectAllEntries () {
    listBox->selectAll (false);
 }
@@ -208,14 +272,18 @@ void PhraseList::lineEntered (const QString &phrase) {
 void PhraseList::speakPhrase (const QString &phrase) {
    QApplication::setOverrideCursor (KCursor::WaitCursor, false);
    KMouthApp *theApp=(KMouthApp *) parentWidget();
-   theApp->getTTSSystem()->speak(phrase);
+   QString language = completion->languageOfWordList (completion->currentWordList());
+   theApp->getTTSSystem()->speak(phrase, language);
    QApplication::restoreOverrideCursor ();
 }
 
 void PhraseList::insertIntoPhraseList (const QString &phrase, bool clearEditLine) {
    int lastLine = listBox->count() - 1;
-   if ((lastLine == -1) || (phrase != listBox->text(lastLine)))
+   if ((lastLine == -1) || (phrase != listBox->text(lastLine))) {
       listBox->insertItem(new PhraseListItem(phrase));
+      if (clearEditLine)
+         completion->addSentence (phrase);
+   }
 
    if (clearEditLine) {
       lineEdit->selectAll();
@@ -363,13 +431,13 @@ void PhraseList::save () {
    }
 
    KURL url;
-   if (book.save (this, i18n("Save As"), url, false) == -1);
+   if (book.save (this, i18n("Save As"), url, false) == -1)
       KMessageBox::sorry(this,i18n("There was an error saving file\n%1").arg( url.url() ));
 }
 
 void PhraseList::open () {
    KURL url=KFileDialog::getOpenURL(QString::null,
-        i18n("*.txt|Plain Text Files (*.txt)\n*.phrasebook|Phrase Books (*.phrasebook)\n*|All Files"), this, i18n("Open File as History"));
+        i18n("*|All Files\n*.phrasebook|Phrase Books (*.phrasebook)\n*.txt|Plain Text Files (*.txt)"), this, i18n("Open File as History"));
 
    if(!url.isEmpty())
       open (url);
